@@ -1,7 +1,7 @@
 package Media::Info::Mplayer;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2019-01-28'; # DATE
+our $VERSION = '0.100'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,6 +69,7 @@ sub get_media_info {
     $info->{duration} = $1      if $stdout =~ /^ID_LENGTH=(.+)/m;
     $info->{num_channels} = $1  if $stdout =~ /^ID_AUDIO_NCH=(.+)/m;
     $info->{num_chapters} = $1  if $stdout =~ /^ID_CHAPTERS=(.+)/m;
+    $info->{rotate} = $1        if $stdout =~ /^ID_VID_\d+_ROTATE=(.+)/m;
     #$info->{_audio_format} = $1 if $stdout =~ /^ID_AUDIO_FORMAT=(.+)/m;
     for (qw/
                AUDIO_FORMAT
@@ -102,7 +103,7 @@ Media::Info::Mplayer - Return information on media file/URL, using mplayer
 
 =head1 VERSION
 
-This document describes version 0.09 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2017-07-10.
+This document describes version 0.100 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2019-01-28.
 
 =head1 SYNOPSIS
 
@@ -138,7 +139,7 @@ Sample result:
 
 Usage:
 
- get_media_info(%args) -> [status, msg, result, meta]
+ get_media_info(%args) -> [status, msg, payload, meta]
 
 Return information on media file/URL, using mplayer.
 
@@ -161,7 +162,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -193,7 +194,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
